nuvolos - The database connectivity library for Nuvolos
=======================================================

Installation
============

.. code:: bash

    $ pip install --upgrade nuvolos

Usage
=====
The library provides two convenience functions for returning a database connection to access table data in Nuvolos.

Documentation and examples available at: https://docs.nuvolos.cloud/data/access-data-from-applications#connecting-with-python